@@ -1,7 +1,7 @@
 // -*- C++ -*-
 /* This is the bullet class definition file.
  * This file is part of
- * ======================================================
+ * ====================================================== 
  *
  *           LyX, The Document Processor
  *
@@ -10,7 +10,7 @@
  *
  *           This file Copyright 1997-1999
  *           Allan Rae
- * ======================================================*/
+ * ====================================================== */
 
 #ifndef BULLET_H
 #define BULLET_H
@@ -21,9 +21,7 @@
 
 #include "LString.h"
 
-#ifdef DEBUG_AS_DEFAULT
-#include <cassert>
-#endif
+#include "support/LAssert.h"
 
 ///
 class Bullet {
@@ -32,10 +30,7 @@ public:
 	Bullet(const int f = -1, const int c = -1, const int s = -1);
 
 	///
-	Bullet(const string &);
-
-	///
-	~Bullet();
+	Bullet(string const &);
 
 	///
 	void setCharacter(const int);
@@ -44,7 +39,7 @@ public:
 	///
 	void setSize(const int);
 	///
-	void setText(const string &);
+	void setText(string const &);
 	///
 	int getCharacter() const;
 	///
@@ -69,28 +64,28 @@ public:
 	
 
 protected:
-#ifdef DEBUG_AS_DEFAULT
+#ifdef ENABLE_ASSERTIONS
 	void testInvariant() const
 		{
-			assert(font >= MIN);
-			assert(font < FONTMAX);
-			assert(character >= MIN);
-			assert(character < CHARMAX);
-			assert(size >= MIN);
-			assert(size < SIZEMAX);
-			assert(user_text >= -1);
-			assert(user_text <= 1);
+			Assert(font >= MIN);
+			Assert(font < FONTMAX);
+			Assert(character >= MIN);
+			Assert(character < CHARMAX);
+			Assert(size >= MIN);
+			Assert(size < SIZEMAX);
+			Assert(user_text >= -1);
+			Assert(user_text <= 1);
 			// now some relational/operational tests
 			if (user_text == 1) {
-				assert(font == -1 && (character == -1 && size == -1));
-				//        assert(!text.empty()); // this isn't necessarily an error
+				Assert(font == -1 && (character == -1 && size == -1));
+				//        Assert(!text.empty()); // this isn't necessarily an error
 			}
 			//      else if (user_text == -1) {
-			//        assert(!text.empty()); // this also isn't necessarily an error
+			//        Assert(!text.empty()); // this also isn't necessarily an error
 			//      }
 			//      else {
 			//        // user_text == 0
-			//        assert(text.empty()); // not usually true
+			//        Assert(text.empty()); // not usually true
 			//      }
 		}
 #endif
@@ -118,9 +113,9 @@ private:
 	///
 	void generateText();
 	///
-	static const string & bulletSize(const short &);
+	static string bulletSize(const short &);
 	///
-	static const string & bulletEntry(const short &, const short &);
+	static string bulletEntry(const short &, const short &);
 
 	///
 	short font;
@@ -151,19 +146,15 @@ private:
 
 /*----------------Inline Bullet Member Functions------------------*/
 
-inline Bullet::Bullet(const string & t) 
+inline Bullet::Bullet(string const & t) 
   :  font(MIN), character(MIN), size(MIN), user_text(1), text(t)
 {
-#ifdef DEBUG_AS_DEFAULT
+#ifdef ENABLE_ASSERTIONS
 	testInvariant();
 #endif
 }
 
 
-inline Bullet::~Bullet()
-{}
-
-
 inline void Bullet::setCharacter(const int c)
 {
 	if (c < MIN || c >= CHARMAX) {
@@ -173,7 +164,7 @@ inline void Bullet::setCharacter(const int c)
 		character = c;
 	}
 	user_text = 0;
-#ifdef DEBUG_AS_DEFAULT
+#ifdef ENABLE_ASSERTIONS
 	testInvariant();
 #endif
 }
@@ -188,7 +179,7 @@ inline void Bullet::setFont(const int f)
 		font = f;
 	}
 	user_text = 0;
-#ifdef DEBUG_AS_DEFAULT
+#ifdef ENABLE_ASSERTIONS
 	testInvariant();
 #endif
 }
@@ -203,18 +194,18 @@ inline void Bullet::setSize(const int s)
 		size = s;
 	}
 	user_text = 0;
-#ifdef DEBUG_AS_DEFAULT
+#ifdef ENABLE_ASSERTIONS
 	testInvariant();
 #endif
 }
 
 
-inline void Bullet::setText(const string & t)
+inline void Bullet::setText(string const & t)
 {
 	font = character = size = MIN;
 	user_text = 1;
 	text = t;
-#ifdef DEBUG_AS_DEFAULT
+#ifdef ENABLE_ASSERTIONS
 	testInvariant();
 #endif
 }
@@ -246,7 +237,7 @@ inline string Bullet::getText() const
 
 inline Bullet & Bullet::operator = (const Bullet & b)
 {
-#ifdef DEBUG_AS_DEFAULT
+#ifdef ENABLE_ASSERTIONS
 	b.testInvariant();
 #endif
 	font = b.font;
@@ -254,14 +245,14 @@ inline Bullet & Bullet::operator = (const Bullet & b)
 	size = b.size;
 	user_text = b.user_text;
 	text = b.text;
-#ifdef DEBUG_AS_DEFAULT
+#ifdef ENABLE_ASSERTIONS
     this->testInvariant();
 #endif
 	return *this;
 }
 
 
-inline const char * Bullet::c_str()
+inline char const * Bullet::c_str()
 {
 	return this->getText().c_str();
 }
@@ -274,5 +265,5 @@ inline const char * Bullet::c_str()
 static Bullet const ITEMIZE_DEFAULTS[4] = { Bullet( 0, 8 ),//"\\(\\bullet\\)"
                                             Bullet( 0, 0 ),//"\\normalfont\\bfseries{--}"
                                             Bullet( 0, 6 ),//"\\(\\ast\\)"
-                                            Bullet( 0,10 ) };//"\\(\\cdot\\)"
+                                            Bullet( 0, 10 ) };//"\\(\\cdot\\)"
 #endif /* BULLET_H_ */
