@@ -1,6 +1,6 @@
 // -*- C++ -*-
 /* This file is part of
- * ======================================================
+ * ====================================================== 
  * 
  *           LyX, The Document Processor
  *	     Copyright (C) 1995 Matthias Ettrich
@@ -8,25 +8,28 @@
  *           This file is Copyright (C) 1996-1998
  *           Lars Gullik Bjnnes
  *
- * ======================================================
+ * ====================================================== 
  */
 
 #ifndef DEP_TABLE_H
 #define DEP_TABLE_H
 
 #include "LString.h"
-#include <cstdio>
+#include <map>
+using std::map;
+using std::pair;
+
+#ifdef __GNUG__
+#pragma interface
+#endif
 
 ///
 class DepTable {
 public:
-	///
-	DepTable();
-	///
 	/** This one is a little bit harder since we need the absolute
 	  filename. Should we insert files with .sty .cls etc as
 	  extension? */
-	void insert(string const &f,
+	void insert(string const & f,
 		    bool upd = false,
 		    unsigned long one = 0,
 		    unsigned long two = 0);
@@ -34,30 +37,24 @@ public:
 	void update();
 
 	///
-	void write(string const &f);
+	void write(string const & f) const;
 	///
-	void read(string const &f);
+	void read(string const & f);
 	/// returns true if any of the files has changed
-	bool sumchange();
+	bool sumchange() const;
+	/// return true if fil has changed.
+	bool haschanged(string const & fil) const;
+	/// return true if a file with extension ext has changed.
+	bool extchanged(string const & ext) const;
 	///
-	bool haschanged(string const &fil);
+	bool exist(string const & fil) const;
+	///
+	void remove_files_with_extension(string const &);
 private:
 	///
-	DepTable(string const &f,
-		 bool upd,
-		 unsigned long one,
-		 unsigned long two);
+	typedef map<string, pair<unsigned long, unsigned long> > DepList;
 	///
-	string file;
-	/// The files new checksum
-	unsigned long new_sum;
-	/// The files old checksum
-	unsigned long old_sum;
-	///
-	DepTable *next;
-		
-	///
-	void write(FILE *f);
+	DepList deplist;
 };
 
 #endif
