@@ -1,13 +1,13 @@
 // -*- C++ -*-
 /* This file is part of
-* ======================================================
+* ====================================================== 
 * 
 *           LyX, The Document Processor
 *        
 *           Copyright (C) 1995 Matthias Ettrich
 *           Copyright (C) 1995-1999 the LyX Team.
 *
-*======================================================*/
+* ====================================================== */
 
 #ifndef LATEXFEATURES_H
 #define LATEXFEATURES_H
@@ -17,6 +17,9 @@
 #pragma interface
 #endif
 
+#include <vector>
+using std::vector;
+
 #include "LString.h"
 
 class BufferParams; 
@@ -31,10 +34,6 @@ class LyXTextClass;
 struct LaTeXFeatures {
 	///
 	LaTeXFeatures(int n) ;
-	///
-	~LaTeXFeatures() {
-		delete[] layout;
-	}
 	/// The packaes needed by the document
 	string getPackages(BufferParams const &params);
 	/// The macros definitions needed by the document
@@ -118,7 +117,7 @@ struct LaTeXFeatures {
 	
 	//@Man: Layouts
 	//@{
-	bool *layout;
+	vector<bool> layout;
 	//@}
 	
 	//@Man: Special features
