@@ -6,18 +6,23 @@
  *  Description: A bitmap table uses a single bitmap to simulate a 2d array 
  *               of bitmap buttons. It can be used to build bitmap menus.
  *               
- *  Copyright (C) 1995,1996 Alejandro Aguilar Sierra 
+ *  Copyright (C) 1995, 1996 Alejandro Aguilar Sierra 
  *
  *  You are free to use and modify this code under the terms of
  *  the GNU General Public Licence version 2 or later. 
  * 
  */ 
 
-#ifndef __BMTABLE_H__
-#define __BMTABLE_H__ 
+#ifndef BMTABLE_H
+#define BMTABLE_H 
 
 #include FORMS_H_LOCATION
 
+#if defined(__cplusplus)
+extern "C"
+{
+#endif
+
 ///
 #define FL_BMTABLE 1500
 /// A flat bitmap table
@@ -34,6 +39,7 @@
  */
 #define FL_BMTABLE_BOXTYPE	FL_UP_BOX
 
+
 ///
 FL_OBJECT *fl_create_bmtable(int, FL_Coord, FL_Coord, 
 			     FL_Coord, FL_Coord, char const *);
@@ -47,7 +53,7 @@ int fl_get_bmtable_numb(FL_OBJECT *ob);
 void fl_set_bmtable(FL_OBJECT *, int pushed, int pos);
 
 /** Number of columns and rows, and the background bitmap */
-void fl_set_bmtable_data(FL_OBJECT *, int, int, int, int , unsigned char *);
+void fl_set_bmtable_data(FL_OBJECT *, int, int, int, int , unsigned char const *);
 ///
 void fl_set_bmtable_pixmap_data(FL_OBJECT *, int, int, char **);
 ///
@@ -84,5 +90,9 @@ void fl_free_bmtable_bitmap(FL_OBJECT *ob);
 /** Free the current pixmap in preparation for installing a new one */
 void fl_free_bmtable_pixmap(FL_OBJECT *ob);
 
-#endif  /* __BMTABLE_H__ */
+#if defined(__cplusplus)
+}
+#endif
+
+#endif  /* BMTABLE_H */
 
