@@ -1,6 +1,6 @@
 // -*- C++ -*-
 /* This file is part of
-* ======================================================
+ * ====================================================== 
 * 
 *           LyX, The Document Processor 	 
 *	    Copyright (C) 1995 Matthias Ettrich
@@ -8,10 +8,10 @@
 *           This file is Copyleft (C) 1996
 *           Lars Gullik Bjnnes
 *
-*======================================================*/
+* ====================================================== */
  
 // Change Log:
-// ===========
+// =========== 
 // 23/03/98   Heinrich Bauer (heinrich.bauer@t-mobil.de)
 // Spots marked "changed Heinrich Bauer, 23/03/98" modified due to the
 // following bug: dvi file export did not work after printing (or previewing)
@@ -19,8 +19,8 @@
 // every time the LyX-file was left unchanged between the two actions mentioned
 // above.
 
-#ifndef _BUFFER_H_
-#define _BUFFER_H_
+#ifndef BUFFER_H
+#define BUFFER_H
 
 #ifdef __GNUG__
 #pragma interface
@@ -32,13 +32,15 @@
 #include "bufferparams.h"
 #include "texrow.h"
 #include "lyxtext.h"
+#include "support/filetools.h"
+#include "lyx_gui_misc.h"
+
 
 class LyXRC;
 class TeXErrors;
 class LaTeXFeatures;
 
 extern void updateAllVisibleBufferRelatedPopups();
-extern void WarnReadonly();
 
 ///
 struct DEPCLEAN {
@@ -47,7 +49,7 @@ struct DEPCLEAN {
 	///
 	string master;
 	///
-	DEPCLEAN *next;
+	DEPCLEAN * next;
 };
 
 /** The buffer object.
@@ -60,7 +62,7 @@ public:
 	/**@name Constructors and destructor */
 	//@{
 	///
-	Buffer(string const & file, LyXRC * lyxrc = 0, bool b= false);
+	Buffer(string const & file, LyXRC * lyxrc = 0, bool b = false);
 	
 	///
 	~Buffer();
@@ -70,23 +72,28 @@ public:
 	//@{
 
 	/** save the buffer's parameters as user default
- 	  This function saves a file user_lyxdir/templates/defaults.lyx 
-	  which parameters are those of the current buffer. This file
-	  is used as a default template when creating a new
-	  file. Returns true on success.
-	  */
+	    This function saves a file user_lyxdir/templates/defaults.lyx 
+	    which parameters are those of the current buffer. This file
+	    is used as a default template when creating a new
+	    file. Returns true on success.
+	*/
 	bool saveParamsAsDefaults();
 
+	/** high-level interface to buffer functionality
+	    This function parses a command string and executes it
+	*/
+	void Dispatch(const string & command);
+
+	/// Maybe we know the function already by number...
+	void Dispatch(int ac, const string & argument);
+
 	/// should be changed to work for a list.
 	void resize()
-	{
-		if (users) {
-			users->resize();
-		} else if (text) {
-			delete text;
-			text = 0;
+		{
+			if (users) {
+				users->resize();
+			}
 		}
-	}
 
 	/// Update window titles of all users
 	void updateTitles();
@@ -95,27 +102,25 @@ public:
 	void resetAutosaveTimers();
 
 	/** Adds the BufferView to the users list.
-	  Later this func will insert the BufferView into a real list,
-	  not just setting a pointer.
-	  */
-	void addUser(BufferView *u) { users = u; }
+	    Later this func will insert the BufferView into a real list,
+	    not just setting a pointer.
+	*/
+	void addUser(BufferView * u) { users = u; }
 
 	/** Removes the BufferView from the users list.
- 	  Since we only can have one at the moment, we just reset it.
-	  */
+	    Since we only can have one at the moment, we just reset it.
+	*/
 	void delUser(BufferView *){ users = 0; }
-
+	
 	///
-	void update(signed char f);
-
-	///
-	void redraw(void){
-              users->redraw(); 
-              users->fitCursor(); 
-              users->updateScrollbar(); }
+	void redraw() {
+		users->redraw(); 
+		users->fitCursor(); 
+		users->updateScrollbar();
+	}
 
         /// Open and lock an updatable inset
-        void open_new_inset(UpdatableInset*);
+        //void open_new_inset(UpdatableInset *);
 
 	///
 	void loadAutoSaveFile();
@@ -123,15 +128,15 @@ public:
 	/** Reads a file. 
 	    Returns false if it fails.
 	    If par is given, the file is inserted. */
-	bool readFile(LyXLex &, LyXParagraph *par = 0);
+	bool readFile(LyXLex &, LyXParagraph * par = 0);
 	
 	/** Reads a file without header.
 	    Returns false, if file is not completely read.
 	    If par is given, the file is inserted. */
-	bool readLyXformat2(LyXLex &,LyXParagraph *par = 0);
+	bool readLyXformat2(LyXLex &, LyXParagraph * par = 0);
 
 	/// Inserts a lyx file at cursor position. Returns false if it fails.
-	bool insertLyXFile(string const & filename);
+	//bool insertLyXFile(string const & filename);
 
 	/// Write file. Returns false if unsuccesful.
 	bool writeFile(string const &, bool);
@@ -220,7 +225,7 @@ public:
 		dvi_clean_orgd = false;
                 nw_clean = false;
 		bak_clean = false;
-		DEPCLEAN* tmp = dep_clean;
+		DEPCLEAN * tmp = dep_clean;
 		while (tmp) {
 			tmp->clean = false;
 			tmp = tmp->next;
@@ -228,82 +233,90 @@ public:
 	}
 
 	///
-	string getFileName() const { return filename; }
+	string const & fileName() const { return filename; }
+
+	/// A transformed version of the file name, adequate for LaTeX  
+	/* The path is stripped if no_path is true (default) */
+	string getLatexName(bool no_path = true) const {
+		return ChangeExtension(MakeLatexName(filename), 
+				       ".tex", no_path); 
+	}
 
 	/// Change name of buffer. Updates "read-only" flag.
-	void setFileName(string const & newfile);
+	void fileName(string const & newfile);
 
 	/// Name of the document's parent
 	void setParentName(string const &);
 
 	/// Is buffer read-only?
-	bool isReadonly() { return read_only; }
+	bool isReadonly() const { return read_only; }
 
 	/// Set buffer read-only flag
-	void setReadonly(bool flag = true) 
-	{
+	void setReadonly(bool flag = true) {
 		if (read_only != flag) {
 			read_only = flag; 
 			updateTitles();
 			updateAllVisibleBufferRelatedPopups();
 		}
 		if (read_only) {
-			WarnReadonly();
+			WarnReadonly(filename);
 		}
 	}
 
 	/// returns true if the buffer contains a LaTeX document
-	bool isLatex();
+	bool isLatex() const;
 	/// returns true if the buffer contains a LinuxDoc document
-	bool isLinuxDoc();
+	bool isLinuxDoc() const;
 	/// returns true if the buffer contains a DocBook document
-	bool isDocBook();
+	bool isDocBook() const;
 	/// returns true if the buffer contains either a LinuxDoc or DocBook document
-	bool isSGML();
+	bool isSGML() const;
         /// returns true if the buffer contains a Wed document
-        bool isLiterate();
+        bool isLiterate() const;
 
 	///
 	void setPaperStuff();
 
+#if 0
 	///
 	void setOldPaperStuff();
+#endif
 	
 	/** Validate a buffer for LaTeX.
-	  This validates the buffer, and returns a struct for use by
-	  makeLaTeX and others. Its main use is to figure out what commands
-	  and packages need to be included in the LaTeX file. It (should)
-	  also check that the needed constructs are there (i.e. that the \refs
-	  points to coresponding \labels). It should perhaps inset "error"
-	  insets to help the user correct obvious mistakes.
-	 */
-	void validate(LaTeXFeatures&); //the correct parameters to be
-				       //included later 
+	    This validates the buffer, and returns a struct for use by
+	    makeLaTeX and others. Its main use is to figure out what commands
+	    and packages need to be included in the LaTeX file. It (should)
+	    also check that the needed constructs are there (i.e. that the \refs
+	    points to coresponding \labels). It should perhaps inset "error"
+	    insets to help the user correct obvious mistakes.
+	*/
+	void validate(LaTeXFeatures &); //the correct parameters to be
+	//included later 
 
 	/** Insert an inset into the buffer
-	  Insert inset into buffer, placing it in a layout of lout,
-	  if no_table make sure that it doesn't end up in a table. */
-	void insertInset(Inset *, string const &lout=string(), 
-			 bool no_table = false);
+	    Insert inset into buffer, placing it in a layout of lout,
+	    if no_table make sure that it doesn't end up in a table. */
+	//void insertInset(Inset *, string const & lout = string(), 
+	//		 bool no_table = false);
 
         ///
-        void setCursorFromRow (int);
+	//void setCursorFromRow (int);
 
 	///
-	string getIncludeonlyList(char delim=',');
+	string getIncludeonlyList(char delim = ',');
 	///
-	string getReferenceList(char delim='|');
+	string getReferenceList(char delim = '|');
 	///
-	string getBibkeyList(char delim='|');
+	string getBibkeyList(char delim = '|');
 	///
-	bool gotoLabel(const string&);
+	//bool gotoLabel(string const &);
 
 	/// removes all autodeletable insets
-	bool removeAutoInsets();
+	//bool removeAutoInsets();
 
 	/** This will clearly have to change later. Later we can have more
-	  than one user per buffer. */
-	BufferView* getUser() const { return users; }
+	    than one user per buffer. */
+	BufferView * getUser() const { return users; }
 
         //@}
 
@@ -318,15 +331,7 @@ public:
 	
 	/** is a list of paragraphs.
 	 */
-	LyXParagraph *paragraph;
-	
-	/** This holds the mapping between buffer paragraphs and screen rows.
-	    Should be moved to BufferView. (Asger)
-	 */
-	LyXText *text;
-
-	///
-	UpdatableInset* the_locking_inset;
+	LyXParagraph * paragraph;
 
 	/// RCS object
 	LyXVC lyxvc;
@@ -340,54 +345,49 @@ public:
 	/** While writing as LaTeX, tells whether we are
 	    doing a 'nice' LaTeX file */
 	bool niceFile;
-protected:
-	///
-        void InsetUnlock();
-	
-	///
-        inline void InsetSleep();
-	
-	///
-        inline void InsetWakeup();
-	
-	///
-        bool inset_slept;
-	
-	///
-        int  slx;
-	///
-	int sly;
+
+	/// Used when typesetting to place errorboxes.
+	TexRow texrow;
 private:
 	///
-	void insertErrors(TeXErrors &);
-	
+	//void insertErrors(TeXErrors &);
+
         ///
-        void linuxDocHandleFootnote(FILE *file,LyXParagraph* &par, int const depth);
+        void linuxDocHandleFootnote(ostream & os,
+				    LyXParagraph * & par, int const depth);
         ///
-	void DocBookHandleCaption(FILE *file, string &inner_tag,
+	void DocBookHandleCaption(ostream & os, string & inner_tag,
 				  int const depth, int desc_on,
-				  LyXParagraph* &par);
+				  LyXParagraph * & par);
         ///
-	void DocBookHandleFootnote(FILE *file,LyXParagraph* &par, int const depth);
+	void DocBookHandleFootnote(ostream & os,
+				   LyXParagraph * & par, int const depth);
 	///
-        void sgmlOpenTag(FILE * file,int depth,string & latexname);
+        void sgmlOpenTag(ostream & os, int depth,
+			 string const & latexname) const;
         ///
-        void sgmlCloseTag(FILE * file,int depth,string & latexname);
+        void sgmlCloseTag(ostream & os, int depth,
+			  string const & latexname) const;
 	///
-	void LinuxDocError(LyXParagraph *par, int pos, char const *message);
+	void LinuxDocError(LyXParagraph * par, int pos, char const * message);
         ///
-	void SimpleLinuxDocOnePar(FILE *file, LyXParagraph *par, int desc_on, int const depth);
+	void SimpleLinuxDocOnePar(ostream & os, LyXParagraph * par,
+				  int desc_on, int const depth);
         ///
-	void SimpleDocBookOnePar(string &file, string &extra, LyXParagraph *par, int & desc_on, int const depth);
+	void SimpleDocBookOnePar(string & file, string & extra,
+				 LyXParagraph * par, int & desc_on,
+				 int const depth);
 
 	/// LinuxDoc.
-	void push_tag(FILE *file, char const *tag, int& pos, char stack[5][3]);
+	void push_tag(ostream & os, char const * tag,
+		      int & pos, char stack[5][3]);
 	
 	/// LinuxDoc.
-	void pop_tag(FILE *file, char const * tag, int& pos, char stack[5][3]);
-
+	void pop_tag(ostream & os, char const * tag,
+		     int & pos, char stack[5][3]);
+	
 	///
-	void RoffAsciiTable(FILE *file, LyXParagraph *par);
+	void RoffAsciiTable(ostream &, LyXParagraph * par);
 
 	/// is save needed
 	bool lyx_clean;
@@ -395,11 +395,11 @@ private:
 	/// is autosave needed
 	bool bak_clean;
 	
-	/// do we need to run LaTeX, changed 23/03/98, Heinrich Bauer
-	/// We have to distinguish between TeX-runs executed in the original
-	/// directory (in which the original LyX-file resides) and TeX-runs
-	/// executed in a temporary directory. The first situation is valid
-	/// for a dvi-export, the latter one for printing or previewing.
+	/** do we need to run LaTeX, changed 23/03/98, Heinrich Bauer
+	    We have to distinguish between TeX-runs executed in the original
+	    directory (in which the original LyX-file resides) and TeX-runs
+	    executed in a temporary directory. The first situation is valid
+	    for a dvi-export, the latter one for printing or previewing. */
 	bool dvi_clean_orgd;
 	bool dvi_clean_tmpd;
 
@@ -407,7 +407,7 @@ private:
         bool nw_clean;
 
 	/// is regenerating .tex necessary
-	DEPCLEAN *dep_clean;
+	DEPCLEAN * dep_clean;
 
 	/// buffer is r/o
 	bool read_only;
@@ -419,50 +419,21 @@ private:
 	float format;
 	
 	/** A list of views using this buffer.
-	  Why not keep a list of the BufferViews that use this buffer?
+	    Why not keep a list of the BufferViews that use this buffer?
 
-	  At least then we don't have to do a lot of magic like:
-	  buffer->lyx_gui->bufferview->updateLayoutChoice. Just ask each
-	  of the buffers in the list of users to do a updateLayoutChoice.
-	  */
-	BufferView *users;
+	    At least then we don't have to do a lot of magic like:
+	    buffer->lyx_gui->bufferview->updateLayoutChoice. Just ask each
+	    of the buffers in the list of users to do a updateLayoutChoice.
+	*/
+	BufferView * users;
 
-	///
-	friend class BufferList;
-	///
-        friend class BufferView;
-
-	/// Used when typesetting to place errorboxes.
-	TexRow texrow;
 };
 
 
 inline  
-void Buffer::InsetSleep()
+void Buffer::setParentName(string const & name)
 {
-    if (the_locking_inset && !inset_slept) {
-	the_locking_inset->GetCursorPos(slx, sly);
-        the_locking_inset->InsetUnlock();
-	inset_slept = true;
-    }
+	params.parentname = name;    
 }
 
-
-inline  
-void Buffer::InsetWakeup()
-{
-    if (the_locking_inset && inset_slept) {
-	the_locking_inset->Edit(slx, sly);
-	inset_slept = false;
-    }	
-}
-
-
-inline  
-void Buffer::setParentName(string const &name)
-{
-    params.parentname = name;    
-}
-
-
 #endif
