@@ -1,16 +1,16 @@
 // -*- C++ -*-
 /* This file is part of
- * ======================================================
+ * ====================================================== 
  * 
  *           LyX, The Document Processor
  * 	 
- *	    Copyright (C) 1995 1996 Matthias Ettrich
- *           and the LyX Team.
+ *           Copyright 1995 Matthias Ettrich
+ *           Copyright 1995-1999 The LyX Team.
  *
- *======================================================*/
+ * ====================================================== */
 
-#ifndef _BUFFERPARAMS_H
-#define _BUFFERPARAMS_H
+#ifndef BUFFERPARAMS_H
+#define BUFFERPARAMS_H
 
 #ifdef __GNUG__
 #pragma interface
@@ -22,6 +22,9 @@
 #include "Spacing.h"
 #include "Bullet.h"
 #include "insets/insetquotes.h"
+#include "layout.h"
+#include "support/block.h"
+
 
 /**
   This class contains all the parameters for this a buffer uses. Some
@@ -30,20 +33,83 @@
   */
 class BufferParams {
 public:
+	///
+	enum PAPER_SIZE {
+		///
+		PAPER_DEFAULT,
+		///
+		PAPER_USLETTER,
+		///
+		PAPER_LEGALPAPER,
+		///
+		PAPER_EXECUTIVEPAPER,
+		///
+		PAPER_A3PAPER,
+		///
+		PAPER_A4PAPER,
+		///
+		PAPER_A5PAPER,
+		///
+		PAPER_B5PAPER
+	};
+	///
+	enum PAPER_PACKAGES {
+		///
+		PACKAGE_NONE,
+		///
+		PACKAGE_A4,
+		///
+		PACKAGE_A4WIDE,
+		///
+		PACKAGE_WIDEMARGINSA4
+	};
+	///
+	enum VMARGIN_PAPER_TYPE {
+		///
+		VM_PAPER_DEFAULT,
+		///
+		VM_PAPER_CUSTOM,
+		///
+		VM_PAPER_USLETTER,
+		///
+		VM_PAPER_USLEGAL,
+		///
+		VM_PAPER_USEXECUTIVE,
+		///
+		VM_PAPER_A3,
+		///
+		VM_PAPER_A4,
+		///
+		VM_PAPER_A5,
+		///
+		VM_PAPER_B3,
+		///
+		VM_PAPER_B4,
+		///
+		VM_PAPER_B5
+	};
+	///
+	enum PARSEP {
+		///
+		PARSEP_INDENT,
+		///
+		PARSEP_SKIP
+	};
+	///
+	enum PAPER_ORIENTATION {
+		///
+		ORIENTATION_PORTRAIT,
+		///
+		ORIENTATION_LANDSCAPE
+	};
 	//@Man: Constructors and Deconstructors
 	//@{
 	///
 	BufferParams();
-	// ///
-	//BufferParams(const BufferParams&);
 	//@}
 
-	/// Dummy destructor to shut up gcc
-	virtual ~BufferParams() {}
-	
 	///
-	void writeFile(FILE *);
-
+	void writeFile(ostream &);
 
 	///
 	void useClassDefaults();
@@ -57,7 +123,7 @@ public:
 	/** Wether paragraphs are separated by using a indent like in
 	  articles or by using a little skip like in letters.
 	  */
-  	char paragraph_separation; // add approp. signedness
+  	PARSEP paragraph_separation;
 	///
   	InsetQuotes::quote_language quotes_language;
 	///
@@ -65,17 +131,17 @@ public:
 	///
   	string fontsize; 
 	///
- 	signed char textclass;
+ 	LyXTextClassList::ClassList::size_type textclass;
 
 	/* this are for the PaperLayout */
-   ///
+	///
   	char papersize; /* the general papersize (papersize2 or paperpackage */ // add approp. signedness
         ///
         char papersize2; /* the selected Geometry papersize */ // add approp. signedness
         ///
         char paperpackage; /* a special paperpackage .sty-file */ // add approp. signedness
         ///
-	char orientation; // add approp. signedness
+	PAPER_ORIENTATION orientation; // add approp. signedness
 	///
         bool use_geometry;
         ///
@@ -105,9 +171,9 @@ public:
 	///
 	Spacing spacing;
 	///
-	signed char secnumdepth;
+	int secnumdepth;
 	///
-	signed char tocdepth;
+	int tocdepth;
 	///
 	string language;
 	///
@@ -119,23 +185,21 @@ public:
 	///
 	string float_placement;
 	///
-	char columns; // add approp. signedness
+	unsigned int columns;
 	///
-	char sides; // add approp. signedness
+	LyXTextClass::PageSides sides;
 	///
 	string pagestyle;
 	///
-	Bullet temp_bullets[4];
+	block<Bullet, 4> temp_bullets;
 	///
-	Bullet user_defined_bullets[4];
+	block<Bullet, 4> user_defined_bullets;
 	///
-	void Copy(BufferParams const &p);
+	void readPreamble(LyXLex &);
 	///
-	virtual void readPreamble(LyXLex &);
+	void readLanguage(LyXLex &);
 	///
-	virtual void readLanguage(LyXLex &);
-	///
-	virtual void readGraphicsDriver(LyXLex &);
+	void readGraphicsDriver(LyXLex &);
 	/// do we allow accents on all chars in this buffer
 	bool allowAccents;
 	///
