@@ -118,7 +118,9 @@ enum kb_action {
 	LFUN_GETNAME,
 	LFUN_NOTIFY,
         LFUN_GOTOFILEROW,   // Edmar 12/23/98
+#if 0
 	LFUN_INSERT_INSET_LATEX,
+#endif
 	LFUN_INSERT_NOTE,
 	LFUN_KMAP_OFF,
 	LFUN_KMAP_PRIM,
@@ -235,12 +237,14 @@ enum kb_action {
 	LFUN_URL,                       // CFO-G 971121
 	LFUN_WORDFINDFORWARD,		// Etienne 980216
 	LFUN_WORDFINDBACKWARD,		// Etienne 980220
-	LFUN_APPENDIX, // ettrich 980505
+	LFUN_APPENDIX,                  // ettrich 980505
 	LFUN_IMPORT, 			// Asger 980724
 	LFUN_MENU_SEPARATOR,            // Asger 990220
+	LFUN_SEQUENCE,                  // Andre' 991111
+	LFUN_SAVEPREFERENCES,           // Lgb 991127
+	LFUN_DATE_INSERT,		// jdblair 20000131
 	LFUN_LASTACTION  /* this marks the end of the table */
 };
 
 ostream & operator<<(ostream &, kb_action);
 #endif
-
