@@ -4,6 +4,8 @@
 #define LYXDEBUG_H
 
 #include "LString.h"
+#include "support/LOstream.h"
+#include "support/lstrings.h"
 
 /** Ideally this should have been a namespace, but since we try to be
     compilable on older C++ compilators too, we use a struct instead.
@@ -41,55 +43,52 @@ struct Debug {
 		///
 		LYXSERVER  = (1 << 12),  // 4096
 		///
-		ROFF       = (1 << 13) 
+		ROFF       = (1 << 13),  // 8192
+		///
+		ACTION     = (1 << 14),   // 16384
+		///
+		LYXLEX     = (1 << 15),
+		///
+		DEPEND     = (1 << 16)
 	};
 	///
 	static const type ANY = type(INFO | INIT | KEY | TOOLBAR |
 				     PARSER | LYXRC | KBMAP | LATEX |
 				     MATHED | FONT | TCLASS | LYXVC |
-				     LYXSERVER | ROFF);
-
+				     LYXSERVER | ROFF | ACTION | LYXLEX |
+				     DEPEND);
+	///
+	friend inline void operator|=(Debug::type & d1, Debug::type d2);
+	
 	/** A function to convert symbolic string names on debug levels
 	    to their numerical value.
 	*/
-	static Debug::type value(string const & val) {
-		int l = Debug::NONE;
-		string v(val);
-		while (!v.empty()) {
-			string::size_type st = v.find(',');
-			string tmp(v.substr(0, st));
-			if (tmp.empty()) break;
-			if (val == "NONE") l |= Debug::NONE;
-			else if (val == "INFO") l |= Debug::INFO;
-			else if (val == "INIT") l |= Debug::INIT;
-			else if (val == "KEY") l |= Debug::KEY; 
-			else if (val == "TOOLBAR") l |= Debug::TOOLBAR;
-			else if (val == "PARSER") l |= Debug::PARSER; 
-			else if (val == "LYXRC") l |= Debug::LYXRC; 
-			else if (val == "KBMAP") l |= Debug::KBMAP;  
-			else if (val == "LATEX") l |= Debug::LATEX;  
-			else if (val == "MATHED") l |= Debug::MATHED; 
-			else if (val == "FONT") l |= Debug::FONT;   
-			else if (val == "TCLASS") l |= Debug::TCLASS; 
-			else if (val == "LYXVC") l |= Debug::LYXVC;  
-			else if (val == "LYXSERVER") l |= Debug::LYXSERVER;
-			else if (val == "ROFF") l |= Debug::ROFF;
-			else break; // unknown string
-			if (st == string::npos) break;
-			v.erase(0, st + 1);
-		}
-		return Debug::type(l);
-	}
+	static Debug::type value(string const & val); 
+
+	/** Display the tags and descriptions of the current debug level 
+	    of ds 
+	*/
+	static void showLevel(ostream & o, type level);
+
+	/** show all the possible tags that can be used for debugging */
+	static void showTags(ostream & o);
+
 };
 
 
+///
+inline void operator|= (Debug::type & d1, Debug::type d2)
+{
+	d1 = static_cast<Debug::type>(d1 | d2);
+}
+
+
 #include "support/DebugStream.h"
 
+
 ///
 ostream & operator<<(ostream & o, Debug::type t);
 
 extern DebugStream lyxerr;
 
 #endif
-
-
