@@ -4,13 +4,13 @@
  *
  *           LyX, The Document Processor
  * 	 
- *	    Copyright (C) 1995 Matthias Ettrich
- *                       1995-1998 The LyX Team
+ *           Copyright 1995 Matthias Ettrich
+ *           Copyright 1995-1999 The LyX Team
  *
- *======================================================*/
+ * ====================================================== */
 
-#ifndef _INSET_LABEL_H
-#define _INSET_LABEL_H
+#ifndef INSET_LABEL_H
+#define INSET_LABEL_H
 
 #ifdef __GNUG__
 #pragma interface
@@ -20,16 +20,14 @@
 #include "LString.h"
 
 ///
-class InsetLabel: public InsetCommand {
+class InsetLabel : public InsetCommand {
 public:
 	///
 	InsetLabel(string const & cmd);
 	///
-	InsetLabel() : InsetCommand("label") {;}
+	InsetLabel() : InsetCommand("label") {}
 	///
-	~InsetLabel();
-	///
-	Inset* Clone();
+	Inset * Clone() const;
 	///
 	Inset::Code LyxCode() const { return Inset::LABEL_CODE; }
 	///
@@ -41,13 +39,13 @@ public:
 	///
 	unsigned char Editable() const { return 0; }
 	///
-	int Latex(FILE *file, signed char fragile);
+	int Latex(ostream &, signed char fragile);
 	///
-	int Latex(string &file, signed char fragile);
+	int Latex(string & file, signed char fragile);
 	///
-	int Linuxdoc(string &file);
+	int Linuxdoc(string & file);
 	///
-	int DocBook(string &file);
+	int DocBook(string & file);
 private:
 	/// This function escapes 8-bit characters
 	string escape(string const &) const;
