@@ -1,12 +1,12 @@
 // -*- C++ -*-
 /* This file is part of*
- * ======================================================
+ * ====================================================== 
  *
  *           LyX, The Document Processor
  * 	 
  *	    Copyright (C) 1995 Matthias Ettrich
  *
- *======================================================*/
+ * ====================================================== */
 
 #ifndef INSET_LATEX_ACCENT_H
 #define INSET_LATEX_ACCENT_H
@@ -27,52 +27,53 @@
   it also can handle other special characters (e.g. Hstroke)
   Initiated by Ivan Schreter, later modified by Lgb.
   */
-class InsetLatexAccent: public Inset {
+class InsetLatexAccent : public Inset {
 public:
 	///
 	InsetLatexAccent(); 
 	///
 	InsetLatexAccent(string const & string);
+#if 0     // the compiler generated version should be ok.
 	///
-	InsetLatexAccent(InsetLatexAccent const&);
+	InsetLatexAccent(InsetLatexAccent const &);
+#endif
 	///
-	~InsetLatexAccent();
+	int Ascent(LyXFont const & font) const;
 	///
-	int Ascent(LyXFont const &font) const;
+	int Descent(LyXFont const & font) const;
 	///
-	int Descent(LyXFont const &font) const;
+	int Width(LyXFont const & font) const;
 	///
-	int Width(LyXFont const &font) const;
+	int Lbearing(LyXFont const & font) const;
 	///
-	bool DisplayISO8859_9(LyXFont font, LyXScreen &scr,
-			      int baseline, float &x);
+	int Rbearing(LyXFont const & font) const;
 	///
-	void Draw(LyXFont font, LyXScreen &scr, int baseline, float &x);
+	bool DisplayISO8859_9(LyXFont font, LyXScreen & scr,
+			      int baseline, float & x);
 	///
-	void Write(FILE *file);
+	void Draw(LyXFont font, LyXScreen & scr, int baseline, float & x);
 	///
-	void Read(LyXLex &lex);
+	void Write(ostream &);
 	///
-	int Latex(FILE *file, signed char fragile);
+	void Read(LyXLex & lex);
 	///
-	int Latex(string &file, signed char fragile);
+	int Latex(ostream &, signed char fragile);
 	///
-	int Linuxdoc(string &file);
+	int Latex(string & file, signed char fragile);
 	///
-	int DocBook(string &file);
+	int Linuxdoc(string & file);
+	///
+	int DocBook(string & file);
 	///
 	bool Deletable() const;
 	///
 	bool DirectWrite() const;
 	///
-	Inset* Clone();
+	Inset * Clone() const;
 	///
 	Inset::Code LyxCode()const;
 	///
-	bool IsEqual(Inset* other);
-	///
 	inline bool CanDisplay();
-private:
 	/// all the accent types
 	enum ACCENT_TYPES{
 		///
@@ -118,7 +119,7 @@ private:
 		///
  		LSLASH
 	};
-
+private:
 	friend ostream & operator<<(ostream &, ACCENT_TYPES);
 	/// Check if we know the modifier and can display it ok on screen.
 	void checkContents();
@@ -129,7 +130,7 @@ private:
 	/// modifier type
 	ACCENT_TYPES  modtype;
 	
-	/// remove dot from 'i' and 'j' or transform l,L into lslash,LSLaSH
+	/// remove dot from 'i' and 'j' or transform l, L into lslash, LSLaSH
 	bool  remdot;
 	/// add something to ascent - accent at the top
 	bool  plusasc;
@@ -145,4 +146,3 @@ bool InsetLatexAccent::CanDisplay()
 }
 
 #endif
-
