@@ -4,13 +4,13 @@
  *
  *           LyX, The Document Processor
  * 	 
- *	    Copyright (C) 1995 Matthias Ettrich
- *                        1996-1998 LyX Team
+ *           Copyright 1995 Matthias Ettrich
+ *           Copyright 1996-1999 the LyX Team.
  * 
- *======================================================*/
+ * ====================================================== */
 
-#ifndef _INSET_LOF_H
-#define _INSET_LOF_H
+#ifndef INSET_LOF_H
+#define INSET_LOF_H
 
 #ifdef __GNUG__
 #pragma interface
@@ -23,29 +23,27 @@
 
 /** Used to insert table of contents
  */
-class InsetLOF: public InsetCommand {
+class InsetLOF : public InsetCommand {
 public:
 	///
-	InsetLOF(): InsetCommand("listoffigures") {}
+	InsetLOF() : InsetCommand("listoffigures") {}
 	///
-	InsetLOF(Buffer *b): InsetCommand("listoffigures"),owner(b) {}
+	InsetLOF(Buffer * b) : InsetCommand("listoffigures"), owner(b) {}
         ///
-        Inset* Clone() { return new InsetLOF(owner); }
+        Inset * Clone() const { return new InsetLOF(owner); }
     	///
 	string getScreenLabel() const { return _("List of Figures"); }
         
-	//void Edit(int, int);
         ///
 	unsigned char Editable() const {
 		return 0; // not yet
 	}
 	///
-	bool Display() const { return true; }
+	bool display() const { return true; }
 	///
 	Inset::Code LyxCode() const { return Inset::LOF_CODE; }
 private:
 	///
-	Buffer *owner;
+	Buffer * owner;
 };
-
 #endif
