@@ -4,13 +4,13 @@
  *
  *           LyX, The Document Processor
  * 	 
- *	    Copyright (C) 1995 Matthias Ettrich
- *                        1996-1998 LyX Team
+ *           Copyright 1995 Matthias Ettrich
+ *           Copyright 1996-1999 LyX Team
  * 
- *======================================================*/
+ * ====================================================== */
 
-#ifndef _INSET_LOT_H
-#define _INSET_LOT_H
+#ifndef INSET_LOT_H
+#define INSET_LOT_H
 
 #ifdef __GNUG__
 #pragma interface
@@ -23,29 +23,28 @@
 
 /** Used to insert table of contents
  */
-class InsetLOT: public InsetCommand {
+class InsetLOT : public InsetCommand {
 public:
 	///
-	InsetLOT(): InsetCommand("listoftables") {}
+	InsetLOT() : InsetCommand("listoftables") {}
 	///
-	InsetLOT(Buffer *b): InsetCommand("listoftables"), owner(b) {}
+	InsetLOT(Buffer * b) : InsetCommand("listoftables"), owner(b) {}
         ///
-        Inset* Clone() { return new InsetLOT(owner); }
+        Inset * Clone() const { return new InsetLOT(owner); }
     	///
 	string getScreenLabel() const { return _("List of Tables"); }
         
-	//void Edit(int, int);
         ///
 	unsigned char Editable() const {
 		return 0; // not yet
 	}
 	///
-	bool Display() const { return true; }
+	bool display() const { return true; }
 	///
 	Inset::Code LyxCode() const { return Inset::LOT_CODE; }
 private:
 	///
-	Buffer *owner;
+	Buffer * owner;
 };
 
 #endif
