@@ -1,15 +1,15 @@
 // -*- C++ -*-
 /* This file is part of*
- * ======================================================
+ * ====================================================== 
  *
  *           LyX, The Document Processor
  * 	 
- *	    Copyright (C) 1997-1998 LyX Team
+ *           Copyright 1997-1999 LyX Team
  * 
- *======================================================*/
+ * ====================================================== */
 
-#ifndef _INSET_PARENT_H
-#define _INSET_PARENT_H
+#ifndef INSET_PARENT_H
+#define INSET_PARENT_H
 
 #ifdef __GNUG__
 #pragma interface
@@ -24,22 +24,22 @@
   Useful to load a parent document from a child document and to
   share parent's properties between preambleless children. 
  */
-class InsetParent: public InsetCommand {
+class InsetParent : public InsetCommand {
 public:
 	/// Non-standard LyX macro
-	InsetParent(): InsetCommand("lyxparent") { }
+	InsetParent() : InsetCommand("lyxparent") {}
 	///
-        InsetParent(string fn, Buffer* owner=0);
-	///
-        ~InsetParent() {}
+        InsetParent(string const & fn, Buffer * owner = 0);
 	/// 
-	int Latex(FILE *file, signed char fragile);
+	int Latex(ostream &, signed char fragile);
 	///
-	int Latex(string &file, signed char fragile);
+	int Latex(string & file, signed char fragile);
         ///
-        Inset* Clone() { return new InsetParent(getContents()); }
+        Inset * Clone() const { return new InsetParent(getContents()); }
     	///
-	string getScreenLabel() const { return string(_("Parent:"))+getContents(); }
+	string getScreenLabel() const {
+		return string(_("Parent:")) + getContents();
+	}
         ///
 	void Edit(int, int);
         ///
@@ -51,5 +51,4 @@ public:
         ///
         void setParent(string fn) { setContents(fn); }
 };
-
 #endif
