@@ -13,13 +13,9 @@
 #pragma interface
 #endif
 
-#include <X11/Xlib.h>
-
 #include "LString.h"
 
 #define KB_PREALLOC  16
-#define KB_HASHSIZE 128   // yes, yes - I know. 128 is not exactly prime :-)
-// ... but we are dealing with ASCII chars mostly.
 
 class kb_keymap;
 class kb_sequence;
@@ -33,7 +29,7 @@ struct kb_key {
 	unsigned int mod;
 	
 	/// Keymap for prefix keys
-	kb_keymap *table;
+	kb_keymap * table;
 	
 	/// Action for !prefix keys
 	int action;
@@ -53,34 +49,27 @@ public:
 	
 	/// Bind a key-sequence to an action
 	/** Returns 0 on success. Otherwise, position in string where
-	  error occured. */
-	int bind(char const* seq, int action);
-	
+	    error occured. */
+	int bind(char const * seq, int action);
+
 	///
-	int print(char* buf, int maxlen) const;
+	void print(string & buf) const;
 	
 	/// Look up a key in the keymap
-	int lookup(KeySym key, unsigned mod, kb_sequence *seq);
+	int lookup(unsigned long key, unsigned mod, kb_sequence * seq);
 
 	/// Given an action, find all keybindings.
 	string findbinding(int action) const;
 private:
 	/// Define a new key sequence
-	int defkey(kb_sequence *seq, int action, int idx = 0);
+	int defkey(kb_sequence * seq, int action, int idx = 0);
 	
 	/// Size of the table (<0: hashtab)
-       int size;
+	int size;
 	
 	/// Holds the defined keys
-	/** Both kinds of tables ends with NoSymbol */
-	union
-	{
-		/// Table for linear array
-		kb_key *table;
-		
-		/// Hash table holding key lists
-		kb_key **htable;
-	};
+	/// Table for linear array, table ends with NoSymbol.
+	kb_key * table;
 };
 
 
@@ -100,8 +89,7 @@ public:
 	
 	
 	///
-	~kb_sequence()
-	{
+	~kb_sequence() {
 		if (sequence != staticseq) {
 			delete sequence;
 			delete modifiers;
@@ -110,14 +98,14 @@ public:
 	
 	/// Add a key to the key sequence and look it up in the curmap
 	/** Add a key to the key sequence and look it up in the curmap
-	  if the latter is defined. */
-	int addkey(KeySym key, unsigned mod, unsigned nmod = 0);
-	
+	    if the latter is defined. */
+	int addkey(unsigned long key, unsigned mod, unsigned nmod = 0);
+
 	///
-	int print(char *buf, int maxlen, bool when_defined = false) const; //RVDK_PATCH_5
+	int print(string & buf, bool when_defined = false) const;
 	
         ///
-	int printOptions(char *buf, int maxlen) const;
+	int printOptions(string & buf) const;
 	
 	/// Make length negative to mark the sequence as deleted
 	void delseq();
@@ -126,26 +114,26 @@ public:
 	char getiso();
 	
 	///
-	KeySym getsym();
+	unsigned long getsym();
 	
 	///
 	void reset();
 	
 	///
-	int parse(char const *s);
+	int parse(char const * s);
 	
 	/// Keymap to use if a new sequence is starting
-	kb_keymap *stdmap;
+	kb_keymap * stdmap;
 	
 	/// Keymap to use for the next key
-	kb_keymap *curmap;
+	kb_keymap * curmap;
 	
 	/// Array holding the current key sequence
 	/** If sequence[length-1] < 0xff it can be used as ISO8859 char */
-	unsigned int *sequence;
+	unsigned int * sequence;
 	
 	///
-	unsigned int *modifiers;
+	unsigned int * modifiers;
 	
 	/// Current length of key sequence
 	int length;
