@@ -1,13 +1,13 @@
 // -*- C++ -*-
 /* This file is part of
-* ======================================================
+* ====================================================== 
 * 
 *           LyX, The Document Processor
 * 	 
 *	    Copyright (C) 1995 1996 Matthias Ettrich
 *           and the LyX Team.
 *
-*======================================================*/
+* ====================================================== */
 
 /* This is the declaration of the LyX class, there should only
  * exist _one_ instance of this in the application. */
@@ -44,7 +44,7 @@ public:
 	/**@name Constructors and Deconstructors */
 	//@{
 	/// the only allowed constructor
-	LyX(int *argc, char *argv[]); // constructor
+	LyX(int * argc, char * argv[]); // constructor
 	// Always is useful a destructor
 	~LyX();
 	//@}
@@ -58,9 +58,9 @@ private:
 	/**@name Constructors and Deconstructors */
 	//@{
 	/// not allowed
-	LyX(const LyX &){;} // not allowed
+	LyX(const LyX &) {} // not allowed
 	/// not allowed
-	LyX(){;} // not allowed
+	LyX() {} // not allowed
 	//@}
 
 	/**@name Private variables */
@@ -68,6 +68,8 @@ private:
 	/// does this user start lyx for the first time?
 	bool first_start;
 	///
+	string batch_command;
+	///
 	struct sigaction act_;
 	//@}
 	/**@name Private Members */
