@@ -1,13 +1,13 @@
 // -*- C++ -*-
 /* This file is part of
- * ======================================================
+ * ====================================================== 
  * 
  *           LyX, The Document Processor
  * 	 
- *	    Copyright (C) 1995 Matthias Ettrich
- *          Copyright (C) 1995-1999 The LyX Team.
+ *	    Copyright 1995 Matthias Ettrich
+ *          Copyright 1995-1999 The LyX Team.
  *
- *======================================================*/
+ * ====================================================== */
 
 #ifndef LYXPARAGRAPH_H
 #define LYXPARAGRAPH_H
@@ -16,22 +16,74 @@
 #pragma interface
 #endif
 
-#include "definitions.h"
+#include <vector>
+#include <list>
+
 #include "insets/lyxinset.h"
-#include "table.h"
-#include "support/textutils.h"
-#include "vspace.h"
 #include "insets/insetbib.h"
+#include "table.h"
+#include "vspace.h"
+#include "layout.h"
+#include "support/block.h"
+
+#define NEW_INSETTABLE 1
+#define NEW_FONTTABLE 1
 
 class BufferParams;
 class LyXBuffer;
-class LyXLayout;
 class TexRow;
 struct LaTeXFeatures;
 
+using std::list;
+
 /// A LyXParagraph holds all text, attributes and insets in a text paragraph
 class LyXParagraph  {
 public:
+	///
+	enum PEXTRA_TYPE {
+		///
+		PEXTRA_NONE,
+		///
+		PEXTRA_INDENT,
+		///
+		PEXTRA_MINIPAGE,
+		///
+		PEXTRA_FLOATFLT
+	};
+	///
+	enum MINIPAGE_ALIGNMENT {
+		///
+		MINIPAGE_ALIGN_TOP,
+		///
+		MINIPAGE_ALIGN_MIDDLE,
+		///
+		MINIPAGE_ALIGN_BOTTOM
+	};
+	///
+	enum META_KIND {
+		///
+		META_FOOTNOTE = 1,
+		///
+		META_MARGIN,
+		///
+		META_FIG,
+		///
+		META_TAB,
+		///
+		META_ALGORITHM,
+		///
+		META_WIDE_FIG,
+		///
+		META_WIDE_TAB,
+		///
+		META_HFILL,
+		///
+		META_NEWLINE,
+		///
+		META_PROTECTED_SEPARATOR,
+		///
+		META_INSET
+	};
 
 	/// The footnoteflag
 	enum footnote_flag {
@@ -64,78 +116,68 @@ public:
 	///
 	LyXParagraph();
 	/// this konstruktor inserts the new paragraph in a list
-	LyXParagraph(LyXParagraph *par);
+	LyXParagraph(LyXParagraph * par);
 	/// the destruktors removes the new paragraph from the list
 	~LyXParagraph();
 
 	///
-	void writeFile(FILE*, BufferParams &, char, char);
-
-	// ///
-	//void writeLaTeX(FILE*, BufferParams &);
-
+	void writeFile(ostream &, BufferParams &, char, char);
 	///
-	void validate(LaTeXFeatures&);
+	void validate(LaTeXFeatures &);
 	
 	///
-	int GetID(){
-		return id;
+	int id() const {
+		return id_;
 	}
 	///
-	void SetID(int id_arg){
-		id = id_arg;
+	void id(int id_arg) {
+		id_ = id_arg;
 	}
-	
-	/** allocates more memory for the specified paragraph
-	  pos is needed to specify the paragraph correctly. Remember the
-	  closed footnotes
-	  */
-	void Enlarge(int pos, int number);
 
-	/** make the allocated memory fit to the needed size
-	  used to make a paragraph smaller
-	  */
-	void FitSize();
-	
 	///
 	void read();
-	
-	///
-	void readSimpleWholeFile(FILE *);
 
 	///
-	LyXParagraph* TeXOnePar(string &file, TexRow &texrow,
-				string &foot, TexRow &foot_texrow,
-				int &foot_count);
+	void readSimpleWholeFile(istream &);
 
 	///
-	LyXParagraph* TeXEnvironment(string &file, TexRow &texrow,
-				     string &foot, TexRow &foot_texrow,
-				     int &foot_count);
+	LyXParagraph * TeXOnePar(string & file, TexRow & texrow,
+				string & foot, TexRow & foot_texrow,
+				int & foot_count);
+
+	///
+	LyXParagraph * TeXEnvironment(string & file, TexRow & texrow,
+				     string & foot, TexRow & foot_texrow,
+				     int & foot_count);
 	
 	///
-	LyXParagraph* Clone();
+	LyXParagraph * Clone() const;
 	
 	///
-	bool HasSameLayout(LyXParagraph *par);
+	bool HasSameLayout(LyXParagraph const * par);
 	
 	///
-	void MakeSameLayout(LyXParagraph *par);
+	void MakeSameLayout(LyXParagraph const * par);
 
 	/// Is it the first par with same depth and layout?
-	bool IsFirstInSequence() {
-		LyXParagraph *dhook = DepthHook(GetDepth());
+	bool IsFirstInSequence() const {
+		LyXParagraph const * dhook = DepthHook(GetDepth());
 		return (dhook == this
 			|| dhook->GetLayout() != GetLayout()
 			|| dhook->GetDepth() != GetDepth());
 	}
 
-	///
-	int size;
-	
-	///
-	char *text;
 
+	///
+	typedef char value_type;
+	///
+	typedef vector<value_type> TextContainer;
+	///
+	typedef int size_type;
+	///
+	TextContainer text;
+	///
+	size_type size() const { return text.size(); }
 	/// 
 	VSpace added_space_top;
 	
@@ -143,7 +185,7 @@ public:
 	VSpace added_space_bottom;
 	
 	///
-	signed char layout;
+	LyXTextClass::LayoutList::size_type layout;
 	
 	/**
 	  \begin{itemize}
@@ -172,7 +214,7 @@ public:
 	bool pagebreak_bottom;
 	
 	///
-	char align;
+	LyXAlignment align;
 	
 	///
 	char depth;
@@ -181,13 +223,12 @@ public:
         bool noindent;
 	
 private:
-	///
-	int counter[10];
+	block<int, 10> counter_;
 public:
 	///
-	void setCounter(int i, int v) { counter[i] = v; }
-	int getCounter(int i) { return counter[i]; }
-	void incCounter(int i) { counter[i]++; }
+	void setCounter(int i, int v) { counter_[i] = v; }
+	int getCounter(int i) const { return counter_[i]; }
+	void incCounter(int i) { counter_[i]++; }
 	///
 	bool start_of_appendix;
 
@@ -222,92 +263,87 @@ public:
 	//@}
 	
 	///
-	int last;
+	LyXParagraph * next;
 	///
-	LyXParagraph *next;
-	///
-	LyXParagraph *previous;
+	LyXParagraph * previous;
 
 	/* table stuff -- begin*/
 	///
-	LyXTable *table;
+	LyXTable * table;
 	/* table stuff -- end*/
 
         /// 
-        InsetBibKey* bibkey;  // ale970302
+        InsetBibKey * bibkey;  // ale970302
 
 	/** these function are able to hide closed footnotes
 	 */
-	LyXParagraph *Next();
+	LyXParagraph * Next();
 	
 	///
-	LyXParagraph *Previous();
+	LyXParagraph * Previous();
+	///
+	LyXParagraph const * Previous() const;
 
 	/** these function are able to hide open and closed footnotes
 	 */ 
-	LyXParagraph *NextAfterFootnote();
+	LyXParagraph * NextAfterFootnote();
 	///
-	LyXParagraph *PreviousBeforeFootnote();
-	///
-	LyXParagraph *LastPhysicalPar();
-	///
-	LyXParagraph *FirstPhysicalPar();
+	LyXParagraph const * NextAfterFootnote() const;
 	
+	///
+	LyXParagraph * PreviousBeforeFootnote();
+	///
+	LyXParagraph * LastPhysicalPar();
+	
+	///
+	LyXParagraph * FirstPhysicalPar();
+	///
+	LyXParagraph const * FirstPhysicalPar() const;
+
 	/// returns the physical paragraph
-	LyXParagraph *ParFromPos(int pos);
+	LyXParagraph * ParFromPos(size_type pos);
 	/// returns the position in the physical par
-	int PositionInParFromPos(int pos);
+	int PositionInParFromPos(size_type pos) const;
 
 	/// for the environments
-	LyXParagraph* DepthHook(int depth);
+	LyXParagraph * DepthHook(int depth);
+	/// for the environments
+	LyXParagraph const * DepthHook(int depth) const;
 	///
-	int BeginningOfMainBody();
+	int BeginningOfMainBody() const;
 	///
-	string GetLabestring();
+	string GetLabestring() const;
 	
 	/// the next two functions are for the manual labels
-	string GetLabelWidthString();
+	string GetLabelWidthString() const;
 	///
-	void SetLabelWidthString(const string &s);
+	void SetLabelWidthString(string const & s);
 	///
-	int GetLayout();
+	LyXTextClass::LayoutList::size_type GetLayout() const;
 	///
-	char GetAlign();
+	char GetAlign() const;
 	///
-	char GetDepth();
+	char GetDepth() const;
 	///
-	void SetLayout(char new_layout);
+	void SetLayout(LyXTextClass::LayoutList::size_type new_layout);
 	///
-	void SetOnlyLayout(char new_layout);
+	void SetOnlyLayout(LyXTextClass::LayoutList::size_type new_layout);
 	///
-	int GetFirstCounter(int i);
+	int GetFirstCounter(int i) const;
 	///
-	int Last();
-	
-	/** This one resets all layout and dtp switches but not the font
-	 of the single characters
-	 */ 
-	void Clear();
+	size_type Last() const;
 	///
-	void Erase(int pos);
-
+	void Erase(size_type pos);
 	/** the flag determines wether the layout should be copied
 	 */ 
-	void BreakParagraph(int pos, int flag);
+	void BreakParagraph(size_type pos, int flag);
 	///
-	void BreakParagraphConservative(int pos);
-
-	/** paste this paragraph with the next one
-	  be carefull, this doesent make any check at all
-	  */ 
-	void PasteParagraph();
-
+	void BreakParagraphConservative(size_type pos);
 	/** Get unistantiated font setting. Returns the difference
 	  between the characters font and the layoutfont.
 	  This is what is stored in the fonttable
-	 */ 
-	LyXFont GetFontSettings(int pos);
-	
+	 */
+	LyXFont GetFontSettings(size_type pos) const;
 	/** Get fully instantiated font. If pos == -1, use the layout
 	  font attached to this paragraph.
 	  If pos == -2, use the label font of the layout attached here.
@@ -315,106 +351,92 @@ public:
 	  attributes with values LyXFont::INHERIT, LyXFont::IGNORE or 
 	  LyXFont::TOGGLE.
 	  */
-	LyXFont getFont(int pos);
-	
+	LyXFont getFont(size_type pos) const;
 	///
-	char GetChar(int pos);
+	char GetChar(size_type pos);
 	///
-        string GetWord(int &);
+	char GetChar(size_type pos) const;
 	///
-	void SetFont(int pos, LyXFont const & font);
+	void SetFont(size_type pos, LyXFont const & font);
+	///
+        string GetWord(size_type &) const;
 	/// Returns the height of the highest font in range
-	LyXFont::FONT_SIZE HighestFontInRange(int startpos, int endpos) const;
+	LyXFont::FONT_SIZE HighestFontInRange(size_type startpos,
+					      size_type endpos) const;
 	///
-	void InsertChar(int pos, char c);
+	void InsertChar(size_type pos, char c);
 	///
-	void InsertInset(int pos, Inset *inset);
+	void InsertInset(size_type pos, Inset * inset);
 	///
-	Inset* GetInset(int pos);
-	
+	Inset * GetInset(size_type pos);
+	///
+	Inset const * GetInset(size_type pos) const;
+	///
+	Inset * ReturnNextInsetPointer(size_type & pos);
+	///
+	void OpenFootnote(size_type pos);
+	///
+	void CloseFootnote(size_type pos);
+	/// important for cut and paste
+	void CopyIntoMinibuffer(size_type pos) const;
+	///
+	void CutIntoMinibuffer(size_type pos);
+	///
+	void InsertFromMinibuffer(size_type pos);
+
+	///
+	bool IsHfill(size_type pos) const;
+	///
+	bool IsInset(size_type pos) const;
+	///
+	bool IsFloat(size_type pos) const;
+	///
+	bool IsNewline(size_type pos) const;
+	///
+	bool IsSeparator(size_type pos) const;
+	///
+	bool IsLineSeparator(size_type pos) const;
+	///
+	bool IsKomma(size_type pos) const;
+	/// Used by the spellchecker
+	bool IsLetter(size_type pos) const;
+	/// 
+	bool IsWord(size_type pos) const;
+
+	/** This one resets all layout and dtp switches but not the font
+	 of the single characters
+	 */ 
+	void Clear();
+
+	/** paste this paragraph with the next one
+	  be carefull, this doesent make any check at all
+	  */ 
+	void PasteParagraph();
+
 	/// used to remove the error messages
 	int AutoDeleteInsets();
 
-	///
-	Inset* ReturnNextInsetPointer(int &pos);
-	
 	/// returns -1 if inset not found
-	int GetPositionOfInset(Inset* inset);
+	int GetPositionOfInset(Inset * inset) const;
 	
 	/// ok and now some footnote functions
 	void OpenFootnotes();
-	///
-	void OpenFootnote(int pos);
+
 	///
 	void CloseFootnotes();
-	///
-	void CloseFootnote(int pos);
    
-	/// important for cut and paste
-	void CopyIntoMinibuffer(int pos);
 	///
-	void CutIntoMinibuffer(int pos);
-	///
-	void InsertFromMinibuffer(int pos);
-	
-	///
-	LyXParagraph *FirstSelfrowPar();
-	
-	///
-	bool IsHfill(int pos) {
-		return IsHfillChar(GetChar(pos));
-	}
-	
-	///
-	bool IsInset(int pos) {
-		return IsInsetChar(GetChar(pos));
-	}
-	
-	///
-	bool IsFloat(int pos) {
-		return IsFloatChar(GetChar(pos));
-	}
-	
-	///
-	bool IsNewline(int pos) {
-		bool tmp=false;
-		if (pos>=0)
-			tmp= IsNewlineChar(GetChar(pos));
-		return tmp;
-	}
-	
-	///
-	bool IsSeparator(int pos) {
-		return IsSeparatorChar(GetChar(pos));
-	}
-	
-	///
-	bool IsLineSeparator(int pos) {
-		return IsLineSeparatorChar(GetChar(pos));
-	}
-	
-	///
-	bool IsKomma(int pos){
-		return IsKommaChar(GetChar(pos));
-	}
-	
-	/// Used by the spellchecker
-	bool IsLetter(int pos);
-	
-	/// 
-	bool IsWord( int pos ) {
-	  return IsWordChar( GetChar(pos) ) ;
-	}
+	LyXParagraph * FirstSelfrowPar();
 
 	///
 	int ClearParagraph(){
-		int i=0;
+		int i = 0;
 		if (!IsDummy() && !table){
 			while (Last()
 			       && (IsNewline(0) 
 				   || IsLineSeparator(0))){
 				Erase(0);
-				i++;
+				++i;
 			}
 		}
 		return i;
@@ -426,7 +448,7 @@ public:
 	  one (or more) paragraphs with the footnote, and finally
 	  the a paragraph with the text after the footnote. Only the
 	  first paragraph keeps information  about layoutparameters, */
-	bool IsDummy(){
+	bool IsDummy() const {
 		return (footnoteflag == LyXParagraph::NO_FOOTNOTE && previous
 			&& previous->footnoteflag != LyXParagraph::NO_FOOTNOTE);
 	}
@@ -434,19 +456,20 @@ public:
         /* If I set a PExtra Indent on one paragraph of a ENV_LIST-TYPE
            I have to set it on each of it's elements */
 	///
-        void SetPExtraType(int type, const char *width, const char *widthp);
+        void SetPExtraType(int type, char const * width, char const * widthp);
 	///
         void UnsetPExtraType();
 	///
-	bool RoffContTableRows(FILE *file, int i, int actcell);
+	bool RoffContTableRows(ostream &, size_type i, int actcell);
 	///
-	bool linuxDocConvertChar(char c, string &sgml_string);
+	void DocBookContTableRows(string & file, string & extra, int & desc_on,
+				  size_type i,
+				  int current_cell_number, int & column);
 	///
-	void SimpleDocBookOneTablePar(string &file, string &extra,
-				      int &desc_on, int depth);
+	bool linuxDocConvertChar(char c, string & sgml_string);
 	///
-	void DocBookContTableRows(string &file, string &extra, int &desc_on,
-				  int i, int current_cell_number, int &column);
+	void SimpleDocBookOneTablePar(string & file, string & extra,
+				      int & desc_on, int depth);
 private:
 	/** A font entry covers a range of positions. Notice that the
 	  entries in the list are inserted in random order.
@@ -456,10 +479,9 @@ private:
 	*/
 	struct FontTable  {
 		/// Start position of paragraph this font attribute covers
-		int pos;
+		size_type pos;
 		/// Ending position of paragraph this font attribute covers
-		int pos_end;
-
+		size_type pos_end;
 		/** Font. Interpretation of the font values:
 		If a value is LyXFont::INHERIT_*, it means that the font 
 		attribute is inherited from either the layout of this
@@ -470,51 +492,71 @@ private:
 		allowed in these font tables.
 		*/
 		LyXFont font;
+#ifndef NEW_FONTTABLE
 		/// Pointer to next font entry
-		FontTable *next;
+		FontTable * next;
+#endif
 	};
 	///
 	struct InsetTable {
 		///
-		int pos;
+		size_type pos;
 		///
-		Inset *inset;
+		Inset * inset;
+#ifndef NEW_INSETTABLE
 		///
-		InsetTable *next;
+		InsetTable * next;
+#endif
 	};
+#ifdef NEW_FONTTABLE
 	///
-	FontTable *fonttable;
+	typedef list<FontTable> FontList;
 	///
-	InsetTable *insettable;
+	FontList fontlist;
+#else
 	///
-	LyXParagraph * TeXDeeper(string &file, TexRow &texrow,
-				   string &foot, TexRow &foot_texrow,
-				   int &foot_count);
+	FontTable * fonttable;
+#endif
+#ifdef NEW_INSETTABLE
 	///
-	LyXParagraph * TeXFootnote(string &file, TexRow &texrow,
-				   string &foot, TexRow &foot_texrow,
-				   int &foot_count);
+	typedef list<InsetTable> InsetList;
 	///
-	bool SimpleTeXOnePar(string &file, TexRow &texrow);
+	InsetList insetlist;
+#else
 	///
-	bool SimpleTeXOneTablePar(string &file, TexRow &texrow);
+	InsetTable * insettable;
+#endif
 	///
-	bool TeXContTableRows(string &file, int i, int current_cell_number,
-                              int &column, TexRow &texrow);
+	LyXParagraph * TeXDeeper(string & file, TexRow & texrow,
+				   string & foot, TexRow & foot_texrow,
+				   int & foot_count);
 	///
-	void SimpleTeXBlanks(string &file, TexRow &texrow,
-			     int const i, int &column, LyXFont const &font,
-			     LyXLayout const * const style);
+	LyXParagraph * TeXFootnote(string & file, TexRow & texrow,
+				   string & foot, TexRow & foot_texrow,
+				   int & foot_count);
 	///
-	void SimpleTeXSpecialChars(string &file, TexRow &texrow,
-				   LyXFont &font, LyXFont &running_font,
-				   LyXFont &basefont, bool &open_font,
-				   LyXLayout const * const style,
-				   int &i, int &column, char const c);
+	bool SimpleTeXOnePar(string & file, TexRow & texrow);
 	///
-	int id;
+	bool SimpleTeXOneTablePar(string & file, TexRow & texrow);
+	///
+	bool TeXContTableRows(string & file, size_type i,
+			      int current_cell_number,
+                              int & column, TexRow & texrow);
+	///
+	void SimpleTeXBlanks(string & file, TexRow & texrow,
+			     size_type const i,
+			     int & column, LyXFont const & font,
+			     LyXLayout const & style);
+	///
+	void SimpleTeXSpecialChars(string & file, TexRow & texrow,
+				   LyXFont & font, LyXFont & running_font,
+				   LyXFont & basefont, bool & open_font,
+				   LyXLayout const & style,
+				   size_type & i,
+				   int & column, char const c);
+	///
+	unsigned int id_;
 	///
 	static unsigned int paragraph_id;
 };
-
 #endif
