@@ -1,13 +1,13 @@
 // -*- C++ -*-
 /* This file is part of
- * ======================================================
+ * ====================================================== 
  * 
  *           LyX, The Document Processor
  * 	 
  *           Copyright 1995 Matthias Ettrich
  *           Copyright 1995-1999 The LyX Team.
  *
- * ======================================================*/
+ * ====================================================== */
 
 #ifndef LYXRC_H
 #define LYXRC_H
@@ -17,6 +17,7 @@
 #endif
 
 #include "toolbar.h"
+#include "bufferparams.h"
 
 /// This contains the runtime configuration of LyX
 class LyXRC {
@@ -24,15 +25,17 @@ public:
 	///
 	LyXRC();
 	///
-	~LyXRC();
+	int read (string const & filename);
 	///
-	int Read (string const & filename);
+	void write(string const & filename) const;
 	///
-        void Print();
+        void print() const;
+	///
+	void output(ostream & os) const;
 	/// Is a bind file already (or currently) read?
 	bool hasBindFile;
 	///
-	int ReadBindFile(string name = "cua");
+	int ReadBindFile(string const & name = "cua");
 	///
 	Toolbar toolbar;
 	///
@@ -75,8 +78,16 @@ public:
         string custom_export_command;
 	///
 	string custom_export_format;
+	///
+	bool pdf_mode;
 	/// program for running latex
 	string latex_command;
+	///
+	string pdflatex_command;
+	///
+	string pdf_to_ps_command;
+	///
+	string dvi_to_ps_command;
         /// program for performing literate programming
         string literate_command;
         string literate_extension;
@@ -94,8 +105,10 @@ public:
 	string view_pspic_command;
 	/// program for viewing dvi output (default "xdvi")
 	string view_dvi_command;
+	/// program for viewing pdf output (default "xpdf")
+	string view_pdf_command;
         /// default paper size for local xdvi/dvips/ghostview/whatever
-        LYX_PAPER_SIZE default_papersize;
+        BufferParams::PAPER_SIZE default_papersize;
 	/// command to run chktex incl. options
 	string chktex_command;
 	/// command to run an html converter incl. options
@@ -118,6 +131,8 @@ public:
 	string lastfiles;
 	/// maximal number of lastfiles
 	unsigned int num_lastfiles;
+	/// shall a backup file be created
+	bool make_backup;
 	/// Zoom factor for screen fonts
 	unsigned int zoom;
 	/// Screen font sizes in points for each font size
@@ -182,6 +197,8 @@ public:
 	string secondary_kbmap;
 	///
 	string lyxpipes;
+	///
+	string date_insert_format;
 
 private:
 	///
