@@ -7,16 +7,12 @@
  *	    Copyright (C) 1995 Matthias Ettrich
  *          Copyright (C) 1995-1999 The LyX Team.
  *
- *======================================================*/
+ * ====================================================== */
 
 
 #ifndef LISTREAM_H
 #define LISTREAM_H 
 
-#ifdef HAVE_CONFIG_H
-#include <config.h> 
-#endif
-
 #ifdef HAVE_ISTREAM
 #include <istream>
 #else 
