@@ -7,16 +7,12 @@
  *	    Copyright (C) 1995 Matthias Ettrich
  *          Copyright (C) 1995-1999 The LyX Team.
  *
- *======================================================*/
+ * ====================================================== */
 
 
 #ifndef LOSTREAM_H
 #define LOSTREAM_H 
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif             
-
 #ifdef HAVE_OSTREAM
 #include <ostream>
 #else 
@@ -25,5 +21,6 @@
 
 using std::ostream;
 using std::endl; 
+using std::flush;
 
 #endif
